@@ -51,13 +51,24 @@ class TemplateFilters(object):
         args = request.args.copy()
         args['page_' + generalview_name] = page
         return url_for(request.endpoint,**dict(new_args.items() + args.to_dict().items()))
+
+
+    @app_template_filter('link_page_size')
+    def link_page_size_filter(self, page_size, generalview_name):
+        """
+        Arguments are passed like: psize_<VIEW_NAME>=<PAGE_NUMBER>
+        """
+        new_args = request.view_args.copy()
+        args = request.args.copy()
+        args['psize_' + generalview_name] = page_size
+        return url_for(request.endpoint,**dict(new_args.items() + args.to_dict().items()))
                 
 
     @app_template_filter('get_link_next')
     def get_link_next_filter(self, s):
         return request.args.get('next')
 
-    # to improve
+    # TODO improve this
     @app_template_filter('set_link_filters')
     def set_link_filters_filter(self, path, filters, pk):
         lnkstr = path
