@@ -95,14 +95,22 @@ class FilterSmaller(BaseFilter):
 class FilterRelation(BaseFilter):
     pass
 
-class FilterRelationOneToMany(FilterRelation):
+class FilterRelationOneToManyEqual(FilterRelation):
     name = lazy_gettext('Relation')
     
     def apply(self, query, value):
         rel_obj = self.datamodel.get_related_obj(self.column_name, value)
         return query.filter(getattr(self.model,self.column_name) == rel_obj)
+
+class FilterRelationOneToManyNotEqual(FilterRelation):
+    name = lazy_gettext('No Relation')
     
-class FilterRelationManyToMany(FilterRelation):
+    def apply(self, query, value):
+        rel_obj = self.datamodel.get_related_obj(self.column_name, value)
+        return query.filter(getattr(self.model,self.column_name) != rel_obj)
+
+    
+class FilterRelationManyToManyEqual(FilterRelation):
     name = lazy_gettext('Relation as Many')
     
     def apply(self, query, value):
@@ -138,16 +146,19 @@ class Filters(object):
     def _get_filters(self, cols, datamodel):
         filters = {}
         for col in cols:
-            filters[col] = self._get_filter_type(col, datamodel)
+            lst_flt = self._get_filter_type(col, datamodel)
+            if lst_flt:
+                filters[col] = lst_flt
         return filters
 
     def _get_filter_type(self, col, datamodel):
         prop = datamodel.get_col_property(col)
         if datamodel.is_relation(prop):
             if datamodel.is_relation_many_to_one(prop):
-                return [FilterRelationOneToMany(col, datamodel)]
+                return [FilterRelationOneToManyEqual(col, datamodel),
+                        FilterRelationOneToManyNotEqual(col, datamodel)]
             elif datamodel.is_relation_many_to_many(prop):
-                return [FilterRelationManyToMany(col, datamodel)]
+                return [FilterRelationManyToManyEqual(col, datamodel)]
         else:
             if datamodel.is_text(col) or datamodel.is_string(col):
                 return [FilterStartsWith(col, datamodel), 
@@ -158,22 +169,17 @@ class Filters(object):
                     FilterNotEndsWith(col, datamodel),
                     FilterNotContains(col, datamodel),
                     FilterNotEqual(col, datamodel),]    
-            elif datamodel.is_integer(col):
+            elif datamodel.is_integer(col) or datamodel.is_date(col) or datamodel.is_datetime(col):
                 return [FilterEqual(col, datamodel),
                     FilterGreater(col, datamodel), 
                     FilterSmaller(col, datamodel),
                     FilterNotEqual(col, datamodel)]
-            elif datamodel.is_date(col):
-                return [FilterEqual(col, datamodel), 
-                    FilterGreater(col, datamodel), 
-                    FilterSmaller(col, datamodel)]
-            elif datamodel.is_datetime(col):
-                return [FilterEqual(col, datamodel), 
-                    FilterGreater(col, datamodel), 
-                    FilterSmaller(col, datamodel)]
+            elif datamodel.is_boolean(col):
+                return [FilterEqual(col, datamodel),
+                    FilterNotEqual(col, datamodel)]
             else:
-                print "Filter type not supported"
-                return []
+                print "Filter type not supported for column: %s" % (col)
+                return None
 
     def clear_filters(self):
         self.filters = []
