@@ -7,7 +7,7 @@ from .filemanager import uuid_originalname
 from .security.decorators import has_access
 from .widgets import FormWidget, ShowWidget, ListWidget, SearchWidget, ListCarousel
 from .actions import ActionItem
-from .models.filters import Filters, FilterRelationOneToMany
+from .models.filters import Filters, FilterRelationOneToManyEqual
 
 def expose(url='/', methods=('GET',)):
     """
@@ -348,7 +348,21 @@ class BaseModelView(BaseView):
                 pages[re_match[0]] = int(request.args.get(arg))
         return pages
 
-
+    def _get_page_size_args(self):
+        """
+            Get page size arguments, returns an int
+            { <VIEW_NAME>: PAGE_NUMBER }
+        
+            Arguments are passed: psize_<VIEW_NAME>=<PAGE_SIZE>
+        
+        """
+        page_sizes = {}
+        for arg in request.args:
+            re_match = re.findall('psize_(.*)', arg)
+            if re_match:
+                page_sizes[re_match[0]] = int(request.args.get(arg))
+        return page_sizes
+        
     def _get_order_args(self):
         """
             Get order arguments, return a dictionary
@@ -551,21 +565,22 @@ class BaseCRUDView(BaseModelView):
                                 page=None, page_size=None):
 
         fk = related_view.datamodel.get_related_fk(self.datamodel.obj)
-        filters = Filters().add_filter(fk, FilterRelationOneToMany, 
+        filters = Filters().add_filter(fk, FilterRelationOneToManyEqual, 
                 related_view.datamodel, self.datamodel.get_pk_value(item))
         return related_view._get_list_widget(filters = filters,
                     order_column = order_column,
                     order_direction = order_direction,
                     page=page, page_size=page_size)
 
-    def _get_related_list_widgets(self, item, orders = {}, pages=None, widgets = {}, **args):
+    def _get_related_list_widgets(self, item, orders = {}, pages=None, page_sizes=None, widgets = {}, **args):
         widgets['related_lists'] = []
         for view in self.related_views:
             if orders.get(view.__class__.__name__):
                 order_column, order_direction = orders.get(view.__class__.__name__)
             else: order_column, order_direction = '',''
             widgets['related_lists'].append(self._get_related_list_widget(item, view, 
-                    order_column, order_direction, page=pages.get(view.__class__.__name__), page_size=view.page_size).get('list'))
+                    order_column, order_direction, 
+                    page=pages.get(view.__class__.__name__), page_size=page_sizes.get(view.__class__.__name__)).get('list'))
         return widgets
     
     def _get_list_widget(self, filters, 
@@ -576,6 +591,7 @@ class BaseCRUDView(BaseModelView):
                         widgets = {}, **args):
 
         """ get joined base filter and current active filter for query """
+        page_size = page_size or self.page_size        
         joined_filters = filters.get_joined_filters(self._base_filters)
         count, lst = self.datamodel.query(joined_filters, order_column, order_direction, page=page, page_size=page_size)
         pks = self.datamodel.get_keys(lst)
@@ -703,14 +719,15 @@ class GeneralView(BaseCRUDView):
             order_column, order_direction = self._get_order_args().get(self.__class__.__name__)
         else: order_column, order_direction = '',''
         page = self._get_page_args().get(self.__class__.__name__)
-
+        page_size = self._get_page_size_args().get(self.__class__.__name__)
+        
         self._get_filter_args()
         
         widgets = self._get_list_widget(filters = self._filters, 
                     order_column = order_column, 
                     order_direction = order_direction, 
                     page = page, 
-                    page_size = self.page_size)
+                    page_size = page_size)
         widgets = self._get_search_widget(form = form, widgets = widgets)
 
         return render_template(self.list_template,
@@ -729,13 +746,15 @@ class GeneralView(BaseCRUDView):
     @has_access
     def show(self, pk):
 
+        pages = self._get_page_args()
+        page_sizes = self._get_page_size_args()
+        orders = self._get_order_args()
+
         widgets = self._get_show_widget(pk)
         item = self.datamodel.get(pk)
-        pages = self._get_page_args()
-        orders = self._get_order_args()
-        
+                
         widgets = self._get_related_list_widgets(item, orders = orders, 
-                pages = pages, widgets = widgets)
+                pages = pages, page_sizes = page_sizes, widgets = widgets)
         
         return render_template(self.show_template,
                            pk = pk,
@@ -788,6 +807,7 @@ class GeneralView(BaseCRUDView):
     def edit(self, pk = 0):
 
         pages = self._get_page_args()
+        page_sizes = self._get_page_size_args()
         orders = self._get_order_args()
         
         item = self.datamodel.get(pk)
@@ -813,7 +833,7 @@ class GeneralView(BaseCRUDView):
             else:
                 widgets = self._get_edit_widget(form = form, exclude_cols = exclude_cols)
                 widgets = self._get_related_list_widgets(item, filters = {}, 
-                        orders = orders, pages = pages, widgets = widgets)
+                        orders = orders, pages = pages, page_sizes=page_sizes, widgets = widgets)
                 return render_template(self.edit_template,
                         title = self.edit_title,
                         widgets = widgets,
@@ -824,7 +844,7 @@ class GeneralView(BaseCRUDView):
             form = form.refresh(obj=item)
             widgets = self._get_edit_widget(form = form, exclude_cols = exclude_cols)
             widgets = self._get_related_list_widgets(item, filters = {}, 
-                        orders = orders, pages = pages, widgets = widgets)                
+                        orders = orders, pages = pages, page_sizes=page_sizes, widgets = widgets)                
             return render_template(self.edit_template,
                             title = self.edit_title,
                             widgets = widgets,
